spadl_conversion: convert opta-events to SPADL

Description Usage Arguments Value

Description

Convert formatted events to SPADL formatted

Usage

1
2
3
4
5
6
7
8
9
## S3 method for class 'opta_events'
convert_events_to_spadl(
  events,
  spadl_cfg = .settings$spadl_config,
  opta_cfg = .settings$opta_config,
  ...
)

convert_events_to_spadl(object, ...)

Arguments

spadl_cfg

list giving the SPADL config. Default is to read it from global package config

opta_cfg

list giving the opta config. Default is to read it from global package config

...

extra parameters currently used

object

tibble such as the object created by .opta_events_from_game()

Value

tibble representing SPADL info.

tibble representing SPADL info.


salembsk/playeraction documentation built on Nov. 10, 2020, 8:03 p.m.