Description Usage Arguments Details
set up the package settings
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | set_db(
json_config_file_name = "config_global_ra.json",
json_config_path = "secrets",
json_config_root = "",
data_provider = c("opta", "inStat", "STATS", "whoScored"),
database_type = c("localhost", "prod", "prod_backup"),
feed_collections = c("events", "fixtures", "players", "gameEvents"),
feats_collections = c("playerKeyPasses"),
spadl_collections = c("features", "action_values"),
spadl_config = "spadl_config.json",
opta_config = "opta_config.json",
instat_config = "instat_config.json",
scores_spadl_model_path = "model_spadl_scores.RDS",
concedes_spadl_model_path = "model_spadl_concedes.RDS",
scores_atomic_model_path = "model_atomic_scores.RDS",
concedes_atomic_model_path = "model_atomic_concedes.RDS",
project_name = "playeraction"
)
|
json_config_file_name, json_config_path, json_config_root |
character info needed to access the global config file. |
database_type |
character type of data-base connection |
project_name |
character project-name |
target_db |
character type of database playeraction |
collections_provider |
character name of collection to connect to from
the |
collections_target |
character name of collection to connect to from
the |
save the package settings in a top-level environment called
.settings. The function is called at loading time with default
arguments.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.