Description Usage Arguments Value
Convert formatted events to SPADL formatted
1 2 3 4 5 6 7 8 9 | ## S3 method for class 'opta_events'
convert_events_to_spadl(
events,
spadl_cfg = .settings$spadl_config,
opta_cfg = .settings$opta_config,
...
)
convert_events_to_spadl(object, ...)
|
spadl_cfg |
list giving the SPADL config. Default is to read it from global package config |
opta_cfg |
list giving the opta config. Default is to read it from global package config |
... |
extra parameters currently used |
object |
tibble such as the object created by
|
tibble representing SPADL info.
tibble representing SPADL info.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.